@@ -66,12 +66,12 @@ def test_config_with_customization_is_valid(betamax_session):
 
 
 def test_license_classifier_read_correctly(betamax_session):
-    pkg = PypiPackage("tomli")
+    pkg = PypiPackage("tomli", session=betamax_session)
     assert pkg.read_license_classifiers() == ['License :: OSI Approved :: MIT License']
 
 
 def test_no_license_classifiers_and_no_license_keyword(betamax_session):
-    pkg = PypiPackage("tomli")
+    pkg = PypiPackage("tomli", session=betamax_session)
     pkg.package_data["info"]["classifiers"] = []
     assert pkg.read_license_classifiers() == []
     with pytest.raises(SystemExit):
@@ -79,26 +79,26 @@ def test_no_license_classifiers_and_no_license_keyword(betamax_session):
 
 
 def test_compliant_license_is_returned(betamax_session):
-    pkg = PypiPackage("tomli")
+    pkg = PypiPackage("tomli", session=betamax_session)
     pkg.classifiers = pkg.read_license_classifiers()
     assert pkg.get_license_from_classifiers(compliant=True) == "MIT"
 
 
 def test_bad_license_if_compliant_is_not_returned(betamax_session):
-    pkg = PypiPackage("tomli")
+    pkg = PypiPackage("tomli", session=betamax_session)
     pkg.classifiers = ["License :: Eiffel Forum License (EFL)"]
     with pytest.raises(SystemExit):
         pkg.get_license_from_classifiers(compliant=True)
 
 
 def test_bad_license_if_not_compliant_is_returned(betamax_session):
-    pkg = PypiPackage("tomli")
+    pkg = PypiPackage("tomli", session=betamax_session)
     pkg.classifiers = ["License :: Eiffel Forum License (EFL)"]
     pkg.get_license_from_classifiers(compliant=False) == "EFL"
 
 
 def test_mix_non_compliant_licenses_wont_work_if_strict(betamax_session):
-    pkg = PypiPackage("tomli")
+    pkg = PypiPackage("tomli", session=betamax_session)
     pkg.classifiers = [
         "License :: Eiffel Forum License (EFL)",
         "License :: OSI Approved :: MIT License",
@@ -108,9 +108,25 @@ def test_mix_non_compliant_licenses_wont_work_if_strict(betamax_session):
 
 
 def test_mix_non_compliant_licenses_work_if_not_strict(betamax_session):
-    pkg = PypiPackage("tomli")
+    pkg = PypiPackage("tomli", session=betamax_session)
     pkg.classifiers = [
         "License :: Eiffel Forum License (EFL)",
         "License :: OSI Approved :: MIT License",
     ]
-    pkg.get_license_from_classifiers(compliant=False) == "EFL and MIT"
\ No newline at end of file
+    pkg.get_license_from_classifiers(compliant=False) == "EFL and MIT"
+
+
+@pytest.mark.parametrize("compliant", (True, False))
+def test_OSI_Approved_is_ignored(betamax_session, compliant):
+    pkg = PypiPackage("tomli", session=betamax_session)
+    pkg.classifiers = [
+        "License :: OSI Approved :: MIT License",
+        "License :: OSI Approved",
+    ]
+    pkg.get_license_from_classifiers(compliant) == "MIT"
+
+
+def test_zip_sdist_is_added_to_source_macro(betamax_session):
+    pkg = PypiPackage("azure-common", session=betamax_session)
+    version = pkg.version()
+    assert pkg.source_url(version) == "%{pypi_source azure-common zip}"
